define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "aquest trim.",
	"field-quarter-short-relative+1": "el trim. que ve",
	"field-tue-relative+-1": "dimarts passat",
	"field-year": "any",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "aquest dimecres",
	"field-wed-relative+1": "dimecres que ve",
	"timeFormat-short": "H:mm",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "el mes passat",
	"field-tue-narrow-relative+0": "aquest dt.",
	"field-tue-narrow-relative+1": "dt. que ve",
	"field-thu-short-relative+0": "aquest dj.",
	"field-day-short-relative+-1": "ahir",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "dj. que ve",
	"field-day-relative+0": "avui",
	"field-day-short-relative+-2": "abans-d’ahir",
	"field-day-relative+1": "demà",
	"field-week-narrow-relative+0": "aquesta setm.",
	"field-day-relative+2": "demà passat",
	"field-week-narrow-relative+1": "la setm. que ve",
	"field-wed-narrow-relative+-1": "dc. passat",
	"field-year-narrow": "any",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "enguany",
	"field-tue-relative+0": "aquest dimarts",
	"field-year-narrow-relative+1": "l’any que ve",
	"field-tue-relative+1": "dimarts que ve",
	"field-weekdayOfMonth": "dia de la setmana del mes",
	"field-second-short": "s",
	"dayPeriods-format-narrow-am": "a. m.",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "dia de la setm. del mes",
	"dayPeriods-format-abbr-am": "a. m.",
	"field-week-relative+0": "aquesta setmana",
	"field-month-relative+0": "aquest mes",
	"field-week-relative+1": "la setmana que ve",
	"field-month-relative+1": "el mes que ve",
	"field-sun-narrow-relative+0": "aquest dg.",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "aquest dl.",
	"field-sun-narrow-relative+1": "dg. que ve",
	"field-mon-short-relative+1": "dl. que ve",
	"field-second-relative+0": "ara",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"GN",
		"FB",
		"MÇ",
		"AB",
		"MG",
		"JN",
		"JL",
		"AG",
		"ST",
		"OC",
		"NV",
		"DS"
	],
	"eraNames": [
		"eB"
	],
	"field-weekOfMonth": "setmana del mes",
	"dayPeriods-standAlone-abbr-pm": "p. m.",
	"field-month-short": "mes",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "dia",
	"field-dayOfYear-short": "dia de l’any",
	"field-year-relative+-1": "l’any passat",
	"dayPeriods-format-wide-am": "a. m.",
	"field-sat-short-relative+-1": "ds. passat",
	"field-hour-relative+0": "aquesta hora",
	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
	"field-second-short-relative+0": "ara",
	"field-wed-relative+-1": "dimecres passat",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "ds. passat",
	"field-second": "segon",
	"days-standAlone-narrow": [
		"dg",
		"dl",
		"dt",
		"dc",
		"dj",
		"dv",
		"ds"
	],
	"dayPeriods-standAlone-wide-pm": "p. m.",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "aquesta hora",
	"field-quarter": "trimestre",
	"field-week-short": "setm.",
	"field-day-narrow-relative+0": "avui",
	"field-day-narrow-relative+1": "demà",
	"field-day-narrow-relative+2": "demà passat",
	"quarters-standAlone-wide": [
		"1r trimestre",
		"2n trimestre",
		"3r trimestre",
		"4t trimestre"
	],
	"days-format-narrow": [
		"dg",
		"dl",
		"dt",
		"dc",
		"dj",
		"dv",
		"ds"
	],
	"field-tue-short-relative+0": "aquest dt.",
	"field-tue-short-relative+1": "dt. que ve",
	"field-month-short-relative+-1": "el mes passat",
	"field-mon-relative+-1": "dilluns passat",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "mes",
	"field-day-narrow": "dia",
	"field-minute-short": "min",
	"field-dayperiod": "a. m./p. m.",
	"field-sat-short-relative+0": "aquest ds.",
	"field-sat-short-relative+1": "ds. que ve",
	"dayPeriods-format-narrow-pm": "p. m.",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL 'de' y G",
	"eraAbbr": [
		"eB"
	],
	"quarters-standAlone-abbr": [
		"1T",
		"2T",
		"3T",
		"4T"
	],
	"dayPeriods-format-abbr-pm": "p. m.",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "aquest dilluns",
	"field-mon-relative+1": "dilluns que ve",
	"field-day-narrow-relative+-1": "ahir",
	"field-year-short": "any",
	"field-day-narrow-relative+-2": "abans-d’ahir",
	"months-format-narrow": [
		"GN",
		"FB",
		"MÇ",
		"AB",
		"MG",
		"JN",
		"JL",
		"AG",
		"ST",
		"OC",
		"NV",
		"DS"
	],
	"field-quarter-relative+-1": "el trimestre passat",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "a. m./p. m.",
	"dayPeriods-standAlone-narrow-am": "a. m.",
	"field-week-narrow-relative+-1": "la setm. passada",
	"days-format-short": [
		"dg.",
		"dl.",
		"dt.",
		"dc.",
		"dj.",
		"dv.",
		"ds."
	],
	"dayPeriods-format-wide-pm": "p. m.",
	"field-dayOfYear": "dia de l’any",
	"field-sat-relative+-1": "dissabte passat",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d/M",
	"field-minute-narrow-relative+0": "aquest minut",
	"field-hour": "hora",
	"months-format-wide": [
		"de gener",
		"de febrer",
		"de març",
		"d’abril",
		"de maig",
		"de juny",
		"de juliol",
		"d’agost",
		"de setembre",
		"d’octubre",
		"de novembre",
		"de desembre"
	],
	"dateFormat-full": "EEEE, dd MMMM y G",
	"field-month-relative+-1": "el mes passat",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "aquest ds.",
	"field-fri-relative+0": "aquest divendres",
	"field-sat-narrow-relative+1": "ds. que ve",
	"field-fri-relative+1": "divendres que ve",
	"field-month-narrow-relative+0": "aquest mes",
	"field-month-narrow-relative+1": "el mes que ve",
	"field-sun-short-relative+0": "aquest dg.",
	"field-sun-short-relative+1": "dg. que ve",
	"field-week-relative+-1": "la setmana passada",
	"field-quarter-short-relative+-1": "el trim. passat",
	"field-minute-short-relative+0": "aquest minut",
	"months-format-abbr": [
		"de gen.",
		"de febr.",
		"de març",
		"d’abr.",
		"de maig",
		"de juny",
		"de jul.",
		"d’ag.",
		"de set.",
		"d’oct.",
		"de nov.",
		"de des."
	],
	"field-quarter-relative+0": "aquest trimestre",
	"field-minute-relative+0": "aquest minut",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "el trimestre que ve",
	"field-wed-short-relative+-1": "dc. passat",
	"dateFormat-short": "dd/MM/y GGGGG",
	"field-thu-short-relative+-1": "dj. passat",
	"field-year-narrow-relative+-1": "l’any passat",
	"days-standAlone-wide": [
		"diumenge",
		"dilluns",
		"dimarts",
		"dimecres",
		"dijous",
		"divendres",
		"dissabte"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "dl. passat",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "dj. passat",
	"field-tue-narrow-relative+-1": "dt. passat",
	"field-weekOfMonth-short": "setm. del mes",
	"dateFormatItem-H": "H",
	"dayPeriods-standAlone-narrow-pm": "p. m.",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "aquest dc.",
	"months-standAlone-wide": [
		"gener",
		"febrer",
		"març",
		"abril",
		"maig",
		"juny",
		"juliol",
		"agost",
		"setembre",
		"octubre",
		"novembre",
		"desembre"
	],
	"field-wed-short-relative+1": "dc. que ve",
	"field-sun-relative+-1": "diumenge passat",
	"days-standAlone-abbr": [
		"dg.",
		"dl.",
		"dt.",
		"dc.",
		"dj.",
		"dv.",
		"ds."
	],
	"dateTimeFormat-full": "{1}, {0}",
	"field-second-narrow-relative+0": "ara",
	"field-weekday": "dia de la setmana",
	"field-day-short-relative+0": "avui",
	"field-quarter-narrow-relative+0": "aquest trim.",
	"field-day-short-relative+1": "demà",
	"field-sat-relative+0": "aquest dissabte",
	"field-quarter-narrow-relative+1": "trim. vinent",
	"field-day-short-relative+2": "demà passat",
	"field-sat-relative+1": "dissabte que ve",
	"field-week-short-relative+0": "aquesta setm.",
	"field-week-short-relative+1": "la setm. que ve",
	"months-standAlone-abbr": [
		"gen.",
		"febr.",
		"març",
		"abr.",
		"maig",
		"juny",
		"jul.",
		"ag.",
		"set.",
		"oct.",
		"nov.",
		"des."
	],
	"field-dayOfYear-narrow": "dia de l’any",
	"field-month-short-relative+0": "aquest mes",
	"field-month-short-relative+1": "el mes que ve",
	"field-weekdayOfMonth-short": "dia de la setm. del mes",
	"timeFormat-full": "H:mm:ss (zzzz)",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "fus horari",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "aquest dj.",
	"field-thu-narrow-relative+1": "dj. que ve",
	"field-sun-narrow-relative+-1": "dg. passat",
	"field-mon-short-relative+-1": "dl. passat",
	"field-thu-relative+0": "aquest dijous",
	"field-thu-relative+1": "dijous que ve",
	"field-fri-short-relative+-1": "dv. passat",
	"field-thu-relative+-1": "dijous passat",
	"field-week": "setmana",
	"quarters-format-wide": [
		"1r trimestre",
		"2n trimestre",
		"3r trimestre",
		"4t trimestre"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "aquest dc.",
	"field-wed-narrow-relative+1": "dc. que ve",
	"field-quarter-narrow-relative+-1": "trim. passat",
	"field-year-short-relative+0": "enguany",
	"field-dayperiod-short": "a. m./p. m.",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-year-short-relative+1": "l’any que ve",
	"field-fri-short-relative+0": "aquest dv.",
	"field-fri-short-relative+1": "dv. que ve",
	"days-standAlone-short": [
		"dg.",
		"dl.",
		"dt.",
		"dc.",
		"dj.",
		"dv.",
		"ds."
	],
	"field-week-short-relative+-1": "la setm. passada",
	"field-hour-narrow-relative+0": "aquesta hora",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "fus horari",
	"quarters-format-abbr": [
		"1T",
		"2T",
		"3T",
		"4T"
	],
	"field-month-narrow": "mes",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "dv. passat",
	"field-year-relative+0": "enguany",
	"field-year-relative+1": "l’any que ve",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "divendres passat",
	"eraNarrow": "eB",
	"field-tue-short-relative+-1": "dt. passat",
	"field-minute-narrow": "min",
	"days-format-wide": [
		"diumenge",
		"dilluns",
		"dimarts",
		"dimecres",
		"dijous",
		"divendres",
		"dissabte"
	],
	"field-mon-narrow-relative+0": "aquest dl.",
	"field-mon-narrow-relative+1": "dl. que ve",
	"field-year-short-relative+-1": "l’any passat",
	"field-zone": "fus horari",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "setm. del mes",
	"field-weekday-narrow": "dia de la setm.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dg. passat",
	"field-day-relative+-1": "ahir",
	"dayPeriods-standAlone-abbr-am": "a. m.",
	"field-day-relative+-2": "abans-d’ahir",
	"field-weekday-short": "dia de la setm.",
	"days-format-abbr": [
		"dg.",
		"dl.",
		"dt.",
		"dc.",
		"dj.",
		"dv.",
		"ds."
	],
	"field-sun-relative+0": "aquest diumenge",
	"field-sun-relative+1": "diumenge que ve",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dia",
	"field-week-narrow": "setm.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "aquest dv.",
	"field-fri-narrow-relative+1": "dv. que ve",
	"dayPeriods-standAlone-wide-am": "a. m."
}
//end v1.x content
);